<div class='nuit-loader nuit-loader-size{{size|default:'32'}}'>
  <div class='container'>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
    <div class="dotwrap"><div class="dot"></div></div>
  </div>
  {% if loading_text %}<span class='nuit-loader-text'>{{loading_text}}</span>{% endif %}
</div>