<div class='pagination-centered'>
<ul class='pagination'>
    <li class='arrow{% if not page_obj.has_previous %} unavailable{% endif %}'><a href='{% if page_obj.has_previous %}?{% query_transform context.request page=page_obj.previous_page_number %}{% endif %}'>&laquo;</a></li>
  {% for page in page_list %}
  <li class='{% if page == page_obj.number %}current unavailable{% endif %}{% if not page %} unavailable{% endif %}'><a href='{% if page %}?{% query_transform context.request page=page %}{% endif %}'>{{page|default:'&hellip;'}}</a></li>
  {% endfor %}
  <li class='arrow{% if not page_obj.has_next %} unavailable{% endif %}'><a href='{% if page_obj.has_next %}?{% query_transform context.request page=page_obj.next_page_number %}{% endif %}'>&raquo;</a></li>
  {% if show_totals %}<li class='unavailable'><a href=''>{{page_obj.start_index}} to {{page_obj.end_index}} of {{page_obj.paginator.count}}</a></li>{% endif %}
</ul>
</div>
